﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Linq;
using System.Windows.Forms;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.MainForm;
using HeuristicLab.PluginInfrastructure;
using HeuristicLab.Problems.DataAnalysis.Interfaces.Classification;

namespace HeuristicLab.Problems.DataAnalysis.Views {
  [View("ClassificationEnsembleSolution View")]
  [Content(typeof(ClassificationEnsembleSolution), false)]
  public partial class ClassificationEnsembleSolutionView : ClassificationSolutionView {
    public ClassificationEnsembleSolutionView() {
      InitializeComponent();
    }

    public new ClassificationEnsembleSolution Content {
      get { return (ClassificationEnsembleSolution)base.Content; }
      set { base.Content = value; }
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      cmbWeightCalculator.Enabled = !Locked && !ReadOnly && Content != null;
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      itemsListView.Items.Remove(itemsListView.FindItemWithText("Model: ClassificationEnsembleModel"));
      if (cmbWeightCalculator.Items.Count == 0) {
        cmbWeightCalculator.Items.AddRange(ApplicationManager.Manager.GetInstances<IClassificationEnsembleSolutionWeightCalculator>().OrderBy(b => b.Name, new NaturalStringComparer()).ToArray());
        if (cmbWeightCalculator.Items.Count > 0) {
          cmbWeightCalculator.SelectedIndex = 0;
        }
      } else {
        Content.WeightCalculator = (IClassificationEnsembleSolutionWeightCalculator)cmbWeightCalculator.SelectedItem;
      }
    }

    protected void cmbWeightCalculator_SelectedIndexChanged(object sender, System.EventArgs e) {
      if (cmbWeightCalculator.SelectedItem != null) {
        Content.WeightCalculator = (IClassificationEnsembleSolutionWeightCalculator)cmbWeightCalculator.SelectedItem;
      }
    }

    #region drag & drop
    protected override void itemsListView_DragDrop(object sender, DragEventArgs e) {
      if (e.Effect != DragDropEffects.None) {
        var droppedData = e.Data.GetData(HeuristicLab.Common.Constants.DragDropDataFormat);
        if (droppedData is IValueParameter) droppedData = ((IValueParameter)droppedData).Value;

        ClassificationEnsembleProblemData ensembleProblemData = droppedData as ClassificationEnsembleProblemData;
        ClassificationProblemData problemData = droppedData as ClassificationProblemData;
        if (ensembleProblemData != null) {
          Content.ProblemData = (ClassificationEnsembleProblemData)ensembleProblemData.Clone();
        } else if (problemData != null) {
          Content.ProblemData = new ClassificationEnsembleProblemData((IClassificationProblemData)problemData.Clone());
        }
      }
    }
    #endregion
  }
}
